@@ -284,9 +284,10 @@ class Batch(object):
         """
         Uploads all supplemental files
         """
-        for af in self.functions.values():
-            for gf in af.files.values():
-                self.upload_to_storages_cache(gf)
+        for item in self.functions.values():
+            for af in item.values():
+                for gf in af.files.values():
+                    self.upload_to_storages_cache(gf)
 
     def create_and_populate_work_dir(self, prev_doc):
         workPath = self.cachePath / "docs" / prev_doc.h
@@ -397,8 +398,9 @@ class Batch(object):
             print("local output directory is %s" % self.localOutputPath)
             for storage in self.storages:
                 storage.reset_output()
-                for doc in self.documents.values():
-                    storage.upload_output(doc.canonical_filename, doc.cache_filepath)
+                for docs in self.documents.values():
+                    for doc in docs.values():
+                        storage.upload_output(doc.canonical_filename, doc.cache_filepath)
                 self.upload_all_supplemental_files()
 
     def render_text(self, text):
@@ -411,8 +413,6 @@ class Batch(object):
         return h, self.render_text(template_text)
 
     def render_file_template(self, template_file):
-        print("Looking for file '%s'" % template_file)
-        print(self.jinja_env.loader.__dict__)
         template = self.jinja_env.get_template(template_file)
         h = hash_for_template_file(self.template_dir + "/%s" % template_file)
         return h, template.render(self.template_data)
