@@ -5,18 +5,30 @@ You need to write your own python script so you can import analytics modules and
 
 It is recommended to import render_file from here into your script.
 """
-
 from precipy.batch import Batch
+import importlib
 import json
+import sys
 
-def render_file(filepath, analytics_modules, storages=None, custom_render_fns=None):
+
+def render_file(filepath, raw_analytics_modules, storages=None, custom_render_fns=None):
     with open(filepath, 'r') as f:
         info = json.load(f)
-    return render_data(info, analytics_modules, 
+    return render_data(info, raw_analytics_modules,
             storages=storages,
             custom_render_fns=custom_render_fns)
 
-def render_data(info, analytics_modules, storages=None, custom_render_fns=None):
+def import_module_or_file(ram):
+    try:
+        return importlib.import_module(ram)
+    except ModuleNotFoundError:
+        spec = importlib.util.spec_from_file_location(ram, "%s.py" % ram)
+        module = importlib.util.module_from_spec(spec)
+        sys.modules[ram] = module
+        spec.loader.exec_module(module)
+        return module
+
+def render_data(info, raw_analytics_modules, storages=None, custom_render_fns=None):
     """
     Runs all analytics then generates any reports, per the configuration file specified by filepath.
 
@@ -30,9 +42,15 @@ def render_data(info, analytics_modules, storages=None, custom_render_fns=None):
         info['custom_render_fns'] = custom_render_fns
     if storages:
         info['storages'] = storages
+
+    analytics_modules = []
+    for ram in raw_analytics_modules:
+        if isinstance(ram, str):
+            am = import_module_or_file(ram)
+        else:
+            am = ram
+        analytics_modules.append(am)
+
     batch = Batch(info)
-    batch.generate_analytics(analytics_modules)
-    batch.generate_documents()
-    print("abuot to publish documents...")
-    batch.publish_documents()
+    batch.run(analytics_modules)
     return batch
